<?php

namespace Drupal\webform_pipedrive\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure token access settings for Pipedrive Webform.
 */
class WebformPipedriveConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {

    // Return the config name to be editable.
    return ['webform_pipedrive.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {

    return 'webform_pipedrive_config_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    // Retrieve current value for the API token.
    $config = $this->config('webform_pipedrive.settings');

    // Define the API token input field.
    $form['accessToken'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pipedrive API Token'),
      '#default_value' => $config->get('accessToken'),
      '#description' => $this->t('Enter your Pipedrive API token to access the Pipedrive Webform integration.'),
      '#required' => TRUE,
    ];

    // Define the Pipedrive API Endpoint input field.
    $form['endpoint'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Pipedrive API Endpoint'),
      '#default_value' => $config->get('endpoint'),
      '#description' => $this->t('Enter your Pipedrive API endpoint URL. For the default Pipedrive API, use: https://api.pipedrive.com/v1/.'),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Save the value entered in the form.
    $this->config('webform_pipedrive.settings')
      ->set('accessToken', $form_state->getValue('accessToken'))
      ->set('endpoint', $form_state->getValue('endpoint'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
