<?php

namespace Drupal\webform_pipedrive\Service;

use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Service to retrieve access token and endpoint from configuration.
 */
class GetAccessToken {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new GetAccessToken service.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The configuration factory.
   */
  public function __construct(ConfigFactoryInterface $configFactory) {
    $this->configFactory = $configFactory;
  }

  /**
   * Retrieves access token and endpoint from configuration.
   *
   * @return array
   *   An associative array containing the access token and endpoint.
   */
  public function accessToken() {
    // Retrieve the configuration for the module.
    $config = $this->configFactory->get('webform_pipedrive.settings');
    // Retrieve access token and endpoint from the configuration.
    $accessToken = $config->get('accessToken');
    $endpoint = $config->get('endpoint');
    // Return the retrieved values as an associative array.
    return [
      'accessToken' => $accessToken,
      'endpoint' => $endpoint,
    ];
  }

}
